﻿using GTANetworkAPI;
using System.Collections.Generic;
using System;
using Lite.GUI;
using Lite.Core;
using LiteSDK;
using Lite.Fractions;

namespace Lite.Jobs
{
    class OrangeFarm : Script
    {
        private static nLog Log = new nLog("OrangeFarm");
        private static Dictionary<int, ColShape> Cols = new Dictionary<int, ColShape>();
        private void cf_onEntityEnterColShape(ColShape shape, Player entity)
        {
            try
            {
                NAPI.Data.SetEntityData(entity, "INTERACTIONCHECK", 383);
            }
            catch (Exception ex) { Log.Write("gp_onEntityEnterColShape: " + ex.Message, nLog.Type.Error); }
        }
        private void cf_onEntityExitColShape(ColShape shape, Player entity)
        {
            try
            {
                NAPI.Data.SetEntityData(entity, "INTERACTIONCHECK", 0);
            }
            catch (Exception ex) { Log.Write("gp_onEntityExitColShape: " + ex.Message, nLog.Type.Error); }
        }
        [ServerEvent(Event.ResourceStart)]
        public void onResourceStart()
        {
            try
            {
                NAPI.Blip.CreateBlip(76, new Vector3(405.3659, 6526.2144, 26.566635), 0.8f, 41, Main.StringToU16("Апельсиновая ферма"), 255, 0, true, 0, 0);

                Cols.Add(1, NAPI.ColShape.CreateCylinderColShape(new Vector3(405.3659, 6526.2144, 26.566635) , 0.5f, 2, 0));// get clothes
                Cols[1].OnEntityEnterColShape += cf_onEntityEnterColShape;
                Cols[1].OnEntityExitColShape += cf_onEntityExitColShape;
                Cols[1].SetData("INTERACT", 383);
                NAPI.TextLabel.CreateTextLabel(Main.StringToU16("~b~Устроиться на работу"), new Vector3(405.3659, 6526.2144, 26.566635), 10F, 0.6F, 0, new Color(0, 180, 0));
                
                int i = 0;
                foreach (var Check in Checkpoints)
                {
                    var col = NAPI.ColShape.CreateCylinderColShape(Check.Position, 1, 2, 0);
                    col.SetData("NUMBER", i);
                    col.OnEntityEnterColShape += PlayerEnterCheckpoint;
                    i++;
                }

            }
            catch (Exception e) { Log.Write("ResourceStart: " + e.Message, nLog.Type.Error); }
        }
        public static void StartWorkDay(Player player)
        {

            if (player.GetData<bool>("ON_WORK"))
            {
                Customization.ApplyCharacter(player);
                player.SetData("ON_WORK", false);
                Trigger.ClientEvent(player, "deleteCheckpoint", 15);
                Trigger.ClientEvent(player, "deleteWorkBlip");
                int UUID = Main.Players[player].UUID;
                Notify.Send(player, NotifyType.Info, NotifyPosition.BottomCenter, $"Вы закончили рабочий день", 3000);
                return;
            }
            else
            {
                Customization.ClearClothes(player, Main.Players[player].Gender);
                if (Main.Players[player].Gender)
                {
                    player.SetClothes(3, 85, 0);
                    player.SetClothes(11, 42, 0);
                    player.SetClothes(4, 41, 0);
                    player.SetClothes(6, 37, 0);
                }
                else
                {
                    player.SetClothes(3, 17, 0);
                    player.SetClothes(11, 150, 1);
                    player.SetClothes(4, 1, 5);
                    player.SetClothes(6, 52, 0);
                }

                var check = WorkManager.rnd.Next(0, Checkpoints.Count - 1);
                player.SetData("WORKCHECK", check);
                Trigger.ClientEvent(player, "createCheckpoint", 15, 1, Checkpoints[check].Position, 1, 0, 255, 0, 0);
                Trigger.ClientEvent(player, "createWorkBlip", Checkpoints[check].Position);

                player.SetData("ON_WORK", true);
                Notify.Send(player, NotifyType.Info, NotifyPosition.BottomCenter, "Вы начали рабочий день", 3000);

                return;
            }
        }
        public static void interactPressed(Player client, int id)
        {
            switch (id)
            {
                case 383:
                    try
                    {
                        if (!Main.Players.ContainsKey(client)) return;
                        StartWorkDay(client);
                    }
                    catch (Exception e) { Log.Write("PlayerExitVehicle: " + e.Message, nLog.Type.Error); }
                    return;
            }

        }

        private static void PlayerEnterCheckpoint(ColShape shape, Player player)
        {
            try
            {
                if (!Main.Players.ContainsKey(player)) return;
                if (!player.GetData<bool>("ON_WORK") ||
                    shape.GetData<int>("NUMBER") != player.GetData<int>("WORKCHECK")) return;

                if (Checkpoints[(int) shape.GetData<int>("NUMBER")].Position.DistanceTo(player.Position) > 3) return;
                
                NAPI.Entity.SetEntityPosition(player,
                    Checkpoints[shape.GetData<int>("NUMBER")].Position + new Vector3(0, 0, 1.2));
                NAPI.Entity.SetEntityRotation(player,
                    new Vector3(0, 0, Checkpoints[shape.GetData<int>("NUMBER")].Heading));
                Main.OnAntiAnim(player);
                Trigger.ClientEvent(player, "orangeOpenMenu");
                player.PlayAnimation("amb@prop_human_movie_studio_light@base", "base", 39);
                //player.SetData("WORKCHECK", -1);
                
            }
            catch (Exception e)
            {
                Log.Write("PlayerEnterCheckpoint: " + e.Message, nLog.Type.Error);
            }
        }
        
        [RemoteEvent("orangeStopWork")]
        private static void orangeStopWork(Player player, int count) {
            try
            {
                if (player != null && Main.Players.ContainsKey(player))
                {
                    player.StopAnimation();
                    Main.OffAntiAnim(player);
                    var tryAdd = nInventory.TryAdd(player, new nItem(ItemType.Orange, count));
                    if (tryAdd == -1 || tryAdd > 0)
                        Notify.Send(player, NotifyType.Error, NotifyPosition.BottomCenter,
                            "Недостаточно места в инвентаре", 3000);
                    else nInventory.Add(player, new nItem(ItemType.Orange, count, ""));
                    var nextCheck = WorkManager.rnd.Next(0, Checkpoints.Count - 1);
                    while (nextCheck == player.GetData<int>("WORKCHECK"))
                        nextCheck = WorkManager.rnd.Next(0, Checkpoints.Count - 1);
                    player.SetData("WORKCHECK", nextCheck);
                    Trigger.ClientEvent(player, "createCheckpoint", 15, 1, Checkpoints[nextCheck].Position, 1,
                        0, 255, 0, 0);
                    Trigger.ClientEvent(player, "createWorkBlip", Checkpoints[nextCheck].Position);
                }
            }
            catch
            {
            }
        }

        private static List<Checkpoint> Checkpoints = new List<Checkpoint>()
        {
        new Checkpoint(new Vector3(370.55966, 6517.139, 27.250238), 42.983704),
        new Checkpoint(new Vector3(355.99628, 6516.697, 27.026285), 49.3378),
        new Checkpoint(new Vector3(339.72092, 6517.7734, 27.811853), 118.93499),
        new Checkpoint(new Vector3(354.40555, 6505.5107, 27.41777), -119.46129),
        new Checkpoint(new Vector3(368.79, 6530.909, 27.305374), -36.101658),
        };
        internal class Checkpoint
        {
            public Vector3 Position { get; }
            public double Heading { get; }

            public Checkpoint(Vector3 pos, double rot)
            {
                Position = pos;
                Heading = rot;
            }
        }
    }
}
